@@ -11,3 +11,7 @@ NULL
 print.geojson <- function( x, ... ) sapply(x, function(x) cat(x, "\n"))
 
 
+handle_digits <- function( digits ) {
+	if( is.null( digits )) return(-1)
+	return( as.integer( digits ) )
+}
